@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -57,16 +57,16 @@ intern void pth_debug(char *file, int line, char *fmt, ...)
     static char str[1024];
     int n;
 
-    errno_preserve;
-    va_start(ap, fmt);
-    sprintf(str, "%d:%s:%04d: ", (int)getpid(), file, line);
-    n = strlen(str);
-    vsprintf(str+n, fmt, ap);
-    va_end(ap);
-    n = strlen(str);
-    str[n++] = '\n';
-    pth_sc(write)(STDERR_FILENO, str, n);
-    errno_restore;
+    errno_shield {
+        va_start(ap, fmt);
+        sprintf(str, "%d:%s:%04d: ", (int)getpid(), file, line);
+        n = strlen(str);
+        vsprintf(str+n, fmt, ap);
+        va_end(ap);
+        n = strlen(str);
+        str[n++] = '\n';
+        pth_sc(write)(STDERR_FILENO, str, n);
+    }
     return;
 }
 
