@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -28,13 +28,13 @@
 
 #if cpp
 
-/* temporarily preserve and restore errno */
-#define errno_preserve \
-        do { pth_errno_storage = errno; } while (0)
-#define errno_restore \
-        do { errno = pth_errno_storage; } while (0)
-#define errno_safe(cmd) \
-        do { int __local_errno = errno; cmd; errno = __local_errno; } while (0)
+/* enclose errno in a block */
+#define errno_shield \
+        for ( pth_errno_storage = errno, \
+              pth_errno_flag = TRUE; \
+              pth_errno_flag; \
+              errno = pth_errno_storage, \
+              pth_errno_flag = FALSE )
 
 /* return plus setting an errno value */
 #if defined(PTH_DEBUG)
@@ -51,4 +51,5 @@
 #endif /* cpp */
 
 intern int pth_errno_storage = 0;
+intern int pth_errno_flag    = 0;
 
