@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -77,10 +77,16 @@ unsigned int pth_sleep(unsigned int sec)
 /* Pth variant of POSIX pthread_sigmask(3) */
 int pth_sigmask(int how, const sigset_t *set, sigset_t *oset)
 {
-    /* that's really easy in PTH, we just call POSIX sigprocmask().
-       Because the Pth machine context switching is written to
-       safe and restore also the complete signal set */
-    return sigprocmask(how, set, oset);
+    int rv;
+
+    /* change the explicitly remembered signal mask copy for the scheduler */
+    if (set != NULL)
+        pth_sc(sigprocmask)(how, &(pth_current->mctx.sigs), NULL);
+
+    /* change the real (per-thread saved/restored) signal mask */
+    rv = pth_sc(sigprocmask)(how, set, oset);
+
+    return rv;
 }
 
 /* Pth variant of POSIX sigwait(3) */
@@ -256,7 +262,7 @@ int pth_select_ev(int nfd, fd_set *rfds, fd_set *wfds,
 }
 
 /* Pth variant of select(2) */
-int pth_poll(struct pollfd *pfd, unsigned int nfd, int timeout)
+int pth_poll(struct pollfd *pfd, nfds_t nfd, int timeout)
 {
     return pth_poll_ev(pfd, nfd, timeout, NULL);
 }
@@ -264,7 +270,7 @@ int pth_poll(struct pollfd *pfd, unsigned int nfd, int timeout)
 /* Pth variant of poll(2) with extra events: 
    NOTICE: THIS HAS TO BE BASED ON pth_select(2) BECAUSE
            INTERNALLY THE SCHEDULER IS ONLY select(2) BASED!! */
-int pth_poll_ev(struct pollfd *pfd, unsigned int nfd, int timeout, pth_event_t ev_extra)
+int pth_poll_ev(struct pollfd *pfd, nfds_t nfd, int timeout, pth_event_t ev_extra)
 {
     fd_set rfds, wfds, efds;
     struct timeval tv, *ptv;
@@ -360,17 +366,18 @@ int pth_poll_ev(struct pollfd *pfd, unsigned int nfd, int timeout, pth_event_t e
 }
 
 /* Pth variant of connect(2) */
-int pth_connect(int s, const struct sockaddr *addr, int addrlen)
+int pth_connect(int s, const struct sockaddr *addr, socklen_t addrlen)
 {
     return pth_connect_ev(s, addr, addrlen, NULL);
 }
 
 /* Pth variant of connect(2) with extra events */
-int pth_connect_ev(int s, const struct sockaddr *addr, int addrlen, pth_event_t ev_extra)
+int pth_connect_ev(int s, const struct sockaddr *addr, socklen_t addrlen, pth_event_t ev_extra)
 {
     pth_event_t ev;
     static pth_key_t ev_key = PTH_KEY_INIT;
-    int rv, err, errlen;
+    int rv, err;
+    socklen_t errlen;
   
     /* try to connect */
     while (   (rv = pth_sc(connect)(s, (struct sockaddr *)addr, addrlen)) == -1 
@@ -398,13 +405,13 @@ int pth_connect_ev(int s, const struct sockaddr *addr, int addrlen, pth_event_t
 }
 
 /* Pth variant of accept(2) */
-int pth_accept(int s, struct sockaddr *addr, int *addrlen)
+int pth_accept(int s, struct sockaddr *addr, socklen_t *addrlen)
 {
     return pth_accept_ev(s, addr, addrlen, NULL);
 }
 
 /* Pth variant of accept(2) with extra events */
-int pth_accept_ev(int s, struct sockaddr *addr, int *addrlen, pth_event_t ev_extra)
+int pth_accept_ev(int s, struct sockaddr *addr, socklen_t *addrlen, pth_event_t ev_extra)
 {
     pth_event_t ev;
     static pth_key_t ev_key = PTH_KEY_INIT;
@@ -440,11 +447,11 @@ int pth_accept_ev(int s, struct sockaddr *addr, int *addrlen, pth_event_t ev_ext
     }
 
     /* restore filedescriptor mode */
-    errno_safe(
+    errno_shield {
         pth_fdmode(s, fdmode); 
         if (rv != -1)
             pth_fdmode(rv, fdmode);
-    );
+    }
 
     pth_debug2("pth_accept_ev: leave to thread \"%s\"", pth_current->name);
     return rv;
@@ -598,7 +605,7 @@ ssize_t pth_write_ev(int fd, const void *buf, size_t nbytes, pth_event_t ev_extr
     }
 
     /* restore filedescriptor mode */
-    errno_safe( pth_fdmode(fd, fdmode) );
+    errno_shield { pth_fdmode(fd, fdmode); }
 
     pth_debug2("pth_write_ev: leave to thread \"%s\"", pth_current->name);
     return rv;
@@ -736,7 +743,7 @@ intern ssize_t pth_readv_faked(int fd, const struct iovec *iov, int iovcnt)
     }
 
     /* remove the temporary buffer */ 
-    errno_safe( free(buffer) );
+    errno_shield { free(buffer); }
 
     /* return number of read bytes */
     return(rv);
@@ -849,7 +856,7 @@ ssize_t pth_writev_ev(int fd, const struct iovec *iov, int iovcnt, pth_event_t e
     }
 
     /* restore filedescriptor mode */
-    errno_safe( pth_fdmode(fd, fdmode) );
+    errno_shield { pth_fdmode(fd, fdmode); }
 
     pth_debug2("pth_writev_ev: leave to thread \"%s\"", pth_current->name);
     return rv;
@@ -894,8 +901,8 @@ intern void pth_writev_iov_advance(const struct iovec *riov, int riovcnt, size_t
         /* advance the virtual pointer */
         while (*liovcnt > 0 && advance > 0) {
             if ((*liov)->iov_len > advance) {
-                (*liov)->iov_base = (void *)((char *)((*liov)->iov_base) + advance);
-                (*liov)->iov_len  -= advance;
+                (*liov)->iov_base = (char *)((*liov)->iov_base) + advance;
+                (*liov)->iov_len -= advance;
                 break;
             }
             else {
@@ -944,7 +951,7 @@ intern ssize_t pth_writev_faked(int fd, const struct iovec *iov, int iovcnt)
     rv = pth_sc(write)(fd, buffer, bytes);
 
     /* remove the temporary buffer */ 
-    errno_safe( free(buffer) );
+    errno_shield { free(buffer); }
 
     return(rv);
 }
@@ -975,7 +982,7 @@ ssize_t pth_pread(int fd, void *buf, size_t nbytes, off_t offset)
     rc = pth_read(fd, buf, nbytes);
     
     /* restore the old offset situation */
-    errno_safe( lseek(fd, old_offset, SEEK_SET) );
+    errno_shield { lseek(fd, old_offset, SEEK_SET); }
 
     /* unprotect and return result of read */
     pth_mutex_release(&mutex);
@@ -1008,7 +1015,7 @@ ssize_t pth_pwrite(int fd, const void *buf, size_t nbytes, off_t offset)
     rc = pth_write(fd, buf, nbytes);
     
     /* restore the old offset situation */
-    errno_safe( lseek(fd, old_offset, SEEK_SET) );
+    errno_shield { lseek(fd, old_offset, SEEK_SET); } 
 
     /* unprotect and return result of write */
     pth_mutex_release(&mutex);
