@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -68,17 +68,15 @@ struct pth_mctx_st {
 #if PTH_MCTX_MTH(mcsc)
 #define pth_mctx_save(mctx) \
         ( (mctx)->error = errno, \
-          sigprocmask(SIG_SETMASK, NULL, &((mctx)->sigs)), \
           getcontext(&(mctx)->uc) )
 #elif PTH_MCTX_MTH(sjlj) && PTH_MCTX_DSP(sjlje)
 #define pth_mctx_save(mctx) \
         ( (mctx)->error = errno, \
-          sigprocmask(SIG_SETMASK, &((mctx)->block), &((mctx)->sigs)), \
+          pth_sc(sigprocmask)(SIG_SETMASK, &((mctx)->block), NULL), \
           pth_sigsetjmp((mctx)->jb) )
 #elif PTH_MCTX_MTH(sjlj)
 #define pth_mctx_save(mctx) \
         ( (mctx)->error = errno, \
-          sigprocmask(SIG_SETMASK, NULL, &((mctx)->sigs)), \
           pth_sigsetjmp((mctx)->jb) )
 #else
 #error "unknown mctx method"
@@ -106,7 +104,7 @@ struct pth_mctx_st {
  */
 #if PTH_MCTX_MTH(sjlj) && PTH_MCTX_DSP(sjlje)
 #define pth_mctx_restored(mctx) \
-        sigprocmask(SIG_SETMASK, &((mctx)->sigs), NULL)
+        pth_sc(sigprocmask)(SIG_SETMASK, &((mctx)->sigs), NULL)
 #else
 #define pth_mctx_restored(mctx) \
         /*nop*/
@@ -167,7 +165,7 @@ intern int pth_mctx_set(
     return TRUE;
 }
 
-#elif PTH_MCTX_MTH(sjlj) && !PTH_MCTX_DSP(sjljlx)
+#elif PTH_MCTX_MTH(sjlj) && !PTH_MCTX_DSP(sjljlx) && !PTH_MCTX_DSP(sjljisc)
 
 /*
  * VARIANT 2: THE SIGNAL STACK TRICK
@@ -198,7 +196,7 @@ intern int pth_mctx_set(
 #if !defined(SS_DISABLE) && defined(SA_DISABLE)
 #define SS_DISABLE SA_DISABLE
 #endif
-#if defined(SA_DISABLE)
+#if !defined(HAVE_SS_SP) && defined(HAVE_SS_BASE)
 #define ss_sp ss_base
 #endif
 
@@ -244,11 +242,10 @@ intern int pth_mctx_set(
      */
     sigemptyset(&sigs);
     sigaddset(&sigs, SIGUSR1);
-    sigprocmask(SIG_BLOCK, &sigs, &osigs);
-    memset((void *)&sa, 0, sizeof(struct sigaction));
+    pth_sc(sigprocmask)(SIG_BLOCK, &sigs, &osigs);
     sa.sa_handler = pth_mctx_set_trampoline;
-    sa.sa_flags = SA_ONSTACK;
     sigemptyset(&sa.sa_mask);
+    sa.sa_flags = SA_ONSTACK;
     if (sigaction(SIGUSR1, &sa, &osa) != 0)
         return FALSE;
     
@@ -319,7 +316,7 @@ intern int pth_mctx_set(
      * Restore the old SIGUSR1 signal handler and mask
      */
     sigaction(SIGUSR1, &osa, NULL);
-    sigprocmask(SIG_SETMASK, &osigs, NULL);
+    pth_sc(sigprocmask)(SIG_SETMASK, &osigs, NULL);
 
     /*
      * Initialize additional ingredients of the machine
@@ -337,7 +334,7 @@ intern int pth_mctx_set(
      */
     mctx_creating      = (volatile pth_mctx_t *)mctx;
     mctx_creating_func = (volatile void (*)(void))func;
-    mctx_creating_sigs = (volatile sigset_t)osigs;
+    memcpy((void *)&mctx_creating_sigs, &osigs, sizeof(sigset_t));
 
     /* 
      * Now enter the trampoline again, but this time not as a signal
@@ -408,7 +405,7 @@ static void pth_mctx_set_bootstrap(void)
     /* 
      * Switch to the final signal mask (inherited from parent)
      */
-    sigprocmask(SIG_SETMASK, (sigset_t *)&mctx_creating_sigs, NULL);
+    pth_sc(sigprocmask)(SIG_SETMASK, (sigset_t *)&mctx_creating_sigs, NULL);
 
     /*
      * Move startup details from static storage to local auto
@@ -465,7 +462,34 @@ intern int pth_mctx_set(
     mctx->jb[0].__jmpbuf[0].__pc = (char *)func;
     mctx->jb[0].__jmpbuf[0].__sp = sk_addr_hi;
 #else
-#error "Unknown Linux (g)libc version and/or platform"
+#error "Unsupported Linux (g)libc version and/or platform"
+#endif
+    sigemptyset(&mctx->sigs);
+    mctx->error = 0;
+    return TRUE;
+}
+
+/*
+ * VARIANT 4: INTERACTIVE SPECIFIC JMP_BUF FIDDLING
+ *
+ * No wonder, Interactive Unix (ISC) 4.x contains Microsoft code, so
+ * it's clear that this beast lacks both sigstack and sigaltstack (about
+ * makecontext we not even have to talk). So our only chance is to
+ * fiddle with it's jmp_buf ingredients, of course. We support only i386
+ * boxes.
+ */
+
+#elif PTH_MCTX_MTH(sjlj) && PTH_MCTX_DSP(sjljisc)
+intern int
+pth_mctx_set(pth_mctx_t *mctx, void (*func)(void),
+                     char *sk_addr_lo, char *sk_addr_hi)
+{
+    pth_mctx_save(mctx);
+#if i386
+    mctx->jb[4] = (int)sk_addr_hi;
+    mctx->jb[5] = (int)func;
+#else
+#error "Unsupported ISC architecture"
 #endif
     sigemptyset(&mctx->sigs);
     mctx->error = 0;
