@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -49,7 +49,8 @@ intern void pth_scheduler_init(void)
 {
     /* create the internal signal pipe */
     if (pipe(pth_sigpipe) == -1) {
-        perror("pipe");
+        fprintf(stderr, "**Pth** INIT: Cannot create internal pipe: %s\n", 
+                strerror(errno));
         abort();
     }
     pth_fdmode(pth_sigpipe[0], PTH_FDMODE_NONBLOCK);
@@ -160,7 +161,7 @@ intern void *pth_scheduler(void *dummy)
 
     /* block all signals in the scheduler thread */
     sigfillset(&sigs);
-    sigprocmask(SIG_SETMASK, &sigs, NULL);
+    pth_sc(sigprocmask)(SIG_SETMASK, &sigs, NULL);
 
     /* initialize the snapshot time for bootstrapping the loop */
     pth_time_set(&snapshot, PTH_TIME_NOW);
@@ -188,6 +189,11 @@ intern void *pth_scheduler(void *dummy)
          * Find next thread in ready queue
          */
         pth_current = pth_pqueue_delmax(&pth_RQ);
+        if (pth_current == NULL) {
+            fprintf(stderr, "**Pth** SCHEDULER INTERNAL ERROR: "
+                            "no more thread(s) available to schedule!?!?\n");
+            abort();
+        }
         pth_debug4("pth_scheduler: thread \"%s\" selected (prio=%d, qprio=%d)",
                    pth_current->name, pth_current->prio, pth_current->q_prio);
 
@@ -575,9 +581,9 @@ intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
     /* replace signal actions for signals we've to catch for events */
     for (sig = 1; sig < PTH_NSIG; sig++) {
         if (sigismember(&pth_sigcatch, sig)) {
-            memset((void *)&sa, 0, sizeof(struct sigaction));
-            sigfillset(&sa.sa_mask);
             sa.sa_handler = pth_sched_eventmanager_sighandler;
+            sigfillset(&sa.sa_mask);
+            sa.sa_flags = 0;
             sigaction(sig, &sa, &osa[sig]);
         }
     }
@@ -585,7 +591,7 @@ intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
     /* allow some signals to be delivered: Either to our
        catching handler or directly to the configured
        handler for signals not catched by events */
-    sigprocmask(SIG_SETMASK, &pth_sigblock, &oss);
+    pth_sc(sigprocmask)(SIG_SETMASK, &pth_sigblock, &oss);
 
     /* now do the polling for filedescriptor I/O and timers 
        WHEN THE SCHEDULER SLEEPS AT ALL, THEN HERE!! */
@@ -595,7 +601,7 @@ intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
                && errno == EINTR) ; 
 
     /* restore signal mask and actions and handle signals */
-    sigprocmask(SIG_SETMASK, &oss, NULL);
+    pth_sc(sigprocmask)(SIG_SETMASK, &oss, NULL);
     for (sig = 1; sig < PTH_NSIG; sig++)
         if (sigismember(&pth_sigcatch, sig))
             sigaction(sig, &osa[sig], NULL);
