@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -68,6 +68,22 @@ unsigned int sleep(unsigned int sec)
 }
 #endif
 
+/* Pth hard wrapper for sigprocmask(2) */
+#if cpp
+#if defined(SYS_sigprocmask)
+#define PTH_SC_sigprocmask(a1,a2,a3) ((int)syscall(SYS_sigprocmask,(a1),(a2),(a3)))
+#else
+#define PTH_SC_sigprocmask sigprocmask
+#endif
+#endif /* cpp */
+#if PTH_SYSCALL_HARD && defined(SYS_sigprocmask)
+int sigprocmask(int how, const sigset_t *set, sigset_t *oset)
+{
+    pth_implicit_init();
+    return pth_sigmask(how, set, oset);
+}
+#endif
+
 /* Pth hard wrapper for sigwait(3) [internally fully emulated] */
 #if PTH_SYSCALL_HARD
 int sigwait(const sigset_t *set, int *sigp)
@@ -151,7 +167,7 @@ int select(int nfds, fd_set *readfds, fd_set *writefds,
 #endif
 #endif /* cpp */
 #if PTH_SYSCALL_HARD && defined(SYS_poll)
-int poll(struct pollfd *pfd, unsigned int nfd, int timeout)
+int poll(struct pollfd *pfd, nfds_t nfd, int timeout)
 {
     pth_implicit_init();
     return pth_poll(pfd, nfd, timeout);
