@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -44,21 +44,21 @@ intern int pth_util_sigdelete(int sig)
     struct sigaction sa, osa;
 
     /* check status of signal */
+    sigpending(&ss);
+    if (!sigismember(&ss, sig))
+        return FALSE;
+
+    /* block signal and remember old mask */
     sigemptyset(&ss);
     sigaddset(&ss, sig);
-    sigprocmask(SIG_BLOCK, &ss, &oss);
-    sigpending(&ss);
-    if (!sigismember(&ss, sig)) {
-        sigprocmask(SIG_SETMASK, &oss, NULL);
-        return FALSE;
-    }
+    pth_sc(sigprocmask)(SIG_BLOCK, &ss, &oss);
     
     /* set signal action to our dummy handler */
-    memset((void *)&sa, 0, sizeof(struct sigaction));
-    sigfillset(&sa.sa_mask);
     sa.sa_handler = pth_util_sigdelete_sighandler;
+    sigfillset(&sa.sa_mask);
+    sa.sa_flags = 0;
     if (sigaction(sig, &sa, &osa) != 0) {
-        sigprocmask(SIG_SETMASK, &oss, NULL);
+        pth_sc(sigprocmask)(SIG_SETMASK, &oss, NULL);
         return FALSE;
     }
 
@@ -69,7 +69,7 @@ intern int pth_util_sigdelete(int sig)
 
     /* restore signal mask and handler */
     sigaction(sig, &osa, NULL);
-    sigprocmask(SIG_SETMASK, &oss, NULL);
+    pth_sc(sigprocmask)(SIG_SETMASK, &oss, NULL);
     return TRUE;
 }
 
