@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -28,22 +28,25 @@
                                   arises you are looking for'' 
                                                  -- Tannenbaum, 'Introduction 
                                                     to Computer Networks' */
-/* include our own Pthread header */
-#define _PTHREAD_PRIVATE
-#include "pthread.h"
-#undef _PTHREAD_PRIVATE
-
-/* include Pth and various other vendor headers */
-#include "pth_p.h"
 
 /*
 **  HEADER STUFF
 */
 
+/*
+ * Include our own Pthread and then the private Pth header.
+ * The order here is very important to get correct namespace hiding!
+ */
+#define _PTHREAD_PRIVATE
+#include "pthread.h"
+#include "pth_p.h"
+#undef _PTHREAD_PRIVATE
+
 /* general success return value */
-#ifndef OK
-#define OK 0
+#ifdef OK
+#undef OK
 #endif
+#define OK 0
 
 /*
 **  GLOBAL STUFF
@@ -944,6 +947,13 @@ int pthread_cond_wait(pthread_cond_t *cond, pthread_mutex_t *mutex)
     return OK;
 }
 
+#ifndef HAVE_STRUCT_TIMESPEC
+struct timespec {
+    time_t  tv_sec;     /* seconds */
+    long    tv_nsec;    /* and nanoseconds */
+};
+#endif
+
 int pthread_cond_timedwait(pthread_cond_t *cond, pthread_mutex_t *mutex, 
                            const struct timespec *abstime)
 {
@@ -1016,13 +1026,13 @@ pid_t __pthread_waitpid(pid_t pid, int *status, int options)
     return pth_waitpid(pid, status, options);
 }
 
-int __pthread_connect(int s, struct sockaddr *addr, int addrlen)
+int __pthread_connect(int s, struct sockaddr *addr, socklen_t addrlen)
 {
     pthread_initialize();
     return pth_connect(s, addr, addrlen);
 }
 
-int __pthread_accept(int s, struct sockaddr *addr, int *addrlen)
+int __pthread_accept(int s, struct sockaddr *addr, socklen_t *addrlen)
 {
     pthread_initialize();
     return pth_accept(s, addr, addrlen);
@@ -1035,7 +1045,7 @@ int __pthread_select(int nfds, fd_set *readfds, fd_set *writefds,
     return pth_select(nfds, readfds, writefds, exceptfds, timeout);
 }
 
-int __pthread_poll(struct pollfd *pfd, unsigned int nfd, int timeout)
+int __pthread_poll(struct pollfd *pfd, nfds_t nfd, int timeout)
 {
     pthread_initialize();
     return pth_poll(pfd, nfd, timeout);
