@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -70,7 +70,7 @@ ssize_t pth_readline_ev(int fd, void *buf, size_t buflen, pth_event_t ev_extra)
 {
     size_t n;
     ssize_t rc;
-    char c, *cp;
+    char c = '\0', *cp;
     readline_buf *rl;
 
     pth_once(&readline_once_ctrl, readline_init, NULL);
