@@ -7,16 +7,16 @@
 **  library which can be found at http://www.gnu.org/software/pth/.
 **
 **  This library is free software; you can redistribute it and/or
-**  modify it under the terms of the GNU Library General Public
+**  modify it under the terms of the GNU Lesser General Public
 **  License as published by the Free Software Foundation; either
-**  version 2 of the License, or (at your option) any later version.
+**  version 2.1 of the License, or (at your option) any later version.
 **
 **  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-**  Library General Public License for more details.
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU Library General Public
+**  You should have received a copy of the GNU Lesser General Public
 **  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 **  USA, or contact Ralf S. Engelschall <rse@engelschall.com>.
@@ -84,13 +84,13 @@ static void *ticker(void *_arg)
 int main(int argc, char *argv[]) 
 {
     char caLine[MAXLINELEN];
-    pth_event_t ev;
-    pth_event_t evt;
+    pth_event_t ev = NULL;
+    pth_event_t evt = NULL;
     pth_t t_worker;
     pth_t t_ticker;
     pth_attr_t t_attr;
-    pth_msgport_t mp;
-    pth_msgport_t mp_worker;
+    pth_msgport_t mp = NULL;
+    pth_msgport_t mp_worker = NULL;
     struct query *q;
     int n;
 
